---
icon: material/grid
---


# Sudoku


!!! tip

    Use the :material-file-eye-outline: icon in the top right to see the source code for this page.


## Example instance

```clingo
--8<-- "examples/sudoku/instance.lp"
```

::: examples/sudoku/encoding.lp
    handler: asp
    options:
        glossary: true
        predicate_table: true
        dependency_graph: true
        encodings:
            git_link: true
            source: true
        start_level: 1
